OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Stvorili ste novu ploču {board}",
    "{user} has created a new board {board}" : "{user} je stvorio novu ploču {board}",
    "You have deleted the board {board}" : "Izbrisali ste ploču {board}",
    "{user} has deleted the board {board}" : "{user} je izbrisao ploču {board}",
    "You have restored the board {board}" : "Vratili ste ploču {board}",
    "{user} has restored the board {board}" : "{user} je vratio ploču {board}",
    "You have shared the board {board} with {acl}" : "Podijelili ste ploču {board} s {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} je podijelio ploču {board} s {acl}",
    "You have removed {acl} from the board {board}" : "Uklonili ste {acl} s ploče {board}",
    "{user} has removed {acl} from the board {board}" : "{user} je uklonio {acl} s ploče {board}",
    "You have renamed the board {before} to {board}" : "Preimenovali ste ploču {before} u {board}",
    "{user} has renamed the board {before} to {board}" : "{user} je preimenovao ploču {before} u {board}",
    "You have archived the board {board}" : "Arhivirali ste ploču {board}",
    "{user} has archived the board {before}" : "{user} je arhivirao ploču {before}",
    "You have unarchived the board {board}" : "Dearhivirali ste ploču {board}",
    "{user} has unarchived the board {before}" : "{user} je dearhivirao ploču {before}",
    "You have created a new list {stack} on board {board}" : "Stvorili ste novi popis {stack} na ploči {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} je stvorio novi popis {stack} na ploči {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Preimenovali ste popis {before} u {stack} na ploči {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} je preimenovao popis {before} u {stack} na ploči {board}",
    "You have deleted list {stack} on board {board}" : "Izbrisali ste popis {stack} na ploči {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} je izbrisao popis {stack} na ploči {board}",
    "You have created card {card} in list {stack} on board {board}" : "Stvorili ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} je stvorio karticu {card} u popisu {stack} na ploči {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Izbrisali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} je izbrisao karticu {card} u popisu {stack} na ploči {board}",
    "You have renamed the card {before} to {card}" : "Preimenovali ste karticu {before} u {card}",
    "{user} has renamed the card {before} to {card}" : "{user} je preimenovao karticu {before} u {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Dodali ste opis kartici {card} u popisu {stack} na ploči {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} je dodao opis kartici {card} u popisu {stack} na ploči {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Ažurirali ste opis kartice {card} u popisu {stack} na ploči {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} je ažurirao opis kartice {card} u popisu {stack} na ploči {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Arhivirali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} je arhivirao karticu {card} u popisu {stack} na ploči {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Dearhivirali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} je dearhivirao karticu {card} u popisu {stack} na ploči {board}",
    "You have removed the due date of card {card}" : "Uklonili ste datum dospijeća kartice {card}",
    "{user} has removed the due date of card {card}" : "{user} je uklonio datum dospijeća kartice {card}",
    "You have set the due date of card {card} to {after}" : "Postavili ste datum dospijeća kartice {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} je postavio datum dospijeća kartice {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Ažurirali ste datum dospijeća kartice {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} je ažurirao datum dospijeća kartice {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Dodali ste oznaku {label} na karticu {card} u popisu {stack} na ploči {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} je dodao oznaku {label} na karticu {card} u popisu {stack} na ploči {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Uklonili ste oznaku {label} s kartice {card} u popisu {stack} na ploči {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} je uklonio oznaku {label} s kartice {card} u popisu {stack} na ploči {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Dodijelili ste {assigneduser} kartici {card} na ploči {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} je dodijelio {assigneduser} kartici {card} na ploči {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Uklonili ste {assigneduser} s kartice {card} na ploči {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} je uklonio {assigneduser} s kartice {card} na ploči {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Premjestili ste karticu {card} iz popisa {stackBefore} u {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} je premjestio karticu {card} iz popisa {stackBefore} u {stack}",
    "You have added the attachment {attachment} to card {card}" : "Dodali ste privitak {attachment} kartici {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} je dodao privitak {attachment} kartici {card}",
    "You have updated the attachment {attachment} on card {card}" : "Ažurirali ste privitak {attachment} na kartici {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} je ažurirao privitak {attachment} na kartici {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Izbrisali ste privitak {attachment} s kartice {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} je izbrisao privitak {attachment} s kartice {card}",
    "You have restored the attachment {attachment} to card {card}" : "Vratili ste privitak {attachment} na karticu {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} je vratio privitak {attachment} na karticu {card}",
    "You have commented on card {card}" : "Komentirali ste karticu {card}",
    "{user} has commented on card {card}" : "{user} je komentirao karticu {card}",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Promjene u <strong>aplikaciji Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Na kartici je stvoren <strong>komentar</strong>",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "No file uploaded or file size exceeds maximum of %s" : "Nijedna datoteka nije otpremljena ili veličina datoteke premašuje maksimalnu veličinu od %s",
    "Upcoming cards" : "Nadolazeće kartice",
    "Load more" : "Učitaj više",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kartica {deck-card} na {deck-board} dosegla je datum dospijeća.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vas spominje u komentaru na „%s”.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vas je spomenuo u komentaru na {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Ploču „%s” je s vama podijelio %s.",
    "{user} has shared {deck-board} with you." : "{user} s vama dijeli {deck-board}.",
    "Deck board" : "Deck ploča",
    "Card comments" : "Komentari o kartici",
    "%s on %s" : "%s na %s",
    "No data was provided to create an attachment." : "Nema podataka za izradu privitka.",
    "Finished" : "Završeno",
    "To review" : "Provjeriti",
    "Action needed" : "Potrebna radnja",
    "Later" : "Kasnije",
    "copy" : "kopiraj",
    "To Do" : "Zadatak",
    "Done" : "Gotovo",
    "Attachments" : "Privici",
    "File" : "Datoteka",
    "Card not found" : "Kartica nije pronađena",
    "Path is already shared with this card" : "Put je već podijeljen s ovom karticom",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
    "Personal planning and team project organization" : "Osobno planiranje i organizacija timskih projekata",
    "Add board" : "Dodaj ploču",
    "Card details" : "Pojedinosti o kartici",
    "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
    "Search by board title" : "Traži po naslovu ploče",
    "Select board" : "Odaberi ploču",
    "Select a board" : "Odaberite ploču",
    "No lists available" : "Nema dostupnih popisa",
    "Select a list" : "Odaberi popis",
    "Move card" : "Premjesti karticu",
    "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
    "Link to card" : "Poveznica na karticu",
    "Select a card" : "Odaberite karticu",
    "Cancel" : "Odustani",
    "This board is read only" : "Ova je ploča samo za čitanje",
    "Drop your files to upload" : "Ispustite datoteke za otpremu",
    "File already exists" : "Datoteka već postoji",
    "A file with the name {filename} already exists." : "Datoteka s nazivom {filename} već postoji.",
    "Do you want to overwrite it?" : "Želite li prepisati?",
    "Overwrite file" : "Prepiši datoteku",
    "Keep existing file" : "Zadrži postojeću datoteku",
    "Add card" : "Dodaj karticu",
    "Archived cards" : "Arhivirane kartice",
    "Add list" : "Dodaj popis",
    "List name" : "Naziv popisa",
    "Apply filter" : "Primijeni filtar",
    "Filter by tag" : "Filtriraj prema oznaci",
    "Filter by assigned user" : "Filtriraj prema dodijeljenom korisniku",
    "Unassigned" : "Nedodijeljeno",
    "Open" : "Otvori",
    "Completed" : "Završeno",
    "Filter by due date" : "Filtriraj prema datumu dospijeća",
    "Overdue" : "Kasni",
    "Next 24 hours" : "Sljedeća 24 sata",
    "Next 7 days" : "Sljedećih 7 dana",
    "Next 30 days" : "Sljedećih 30 dana",
    "No due date" : "Nema datuma dospijeća",
    "Clear filter" : "Ukloni filtar",
    "Hide archived cards" : "Sakrij arhivirane kartice",
    "Show archived cards" : "Prikaži arhivirane kartice",
    "Toggle compact mode" : "Prebaci u kompaktni način rada",
    "Open details" : "Otvori pojedinosti",
    "Details" : "Pojedinosti",
    "Loading board" : "Učitavanje ploče",
    "Board not found" : "Ploča nije pronađena",
    "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
    "Sharing" : "Dijeljenje",
    "Tags" : "Oznake",
    "Deleted items" : "Izbrisane stavke",
    "Activity" : "Aktivnost",
    "Deleted lists" : "Izbrisani popisi",
    "Undo" : "Poništi",
    "Deleted cards" : "Izbrisane kartice",
    "Failed to create share with {displayName}" : "Dijeljenje s {displayName} nije uspjelo",
    "Transfer" : "Prijenos",
    "No participants found" : "Nije pronađen nijedan sudionik",
    "Board owner" : "Vlasnik ploče",
    "(Group)" : "(Grupa)",
    "Can edit" : "Uređivanje moguće",
    "Can share" : "Dijeljenje moguće",
    "Can manage" : "Upravljanje moguće",
    "Owner" : "Vlasnik",
    "Delete" : "Izbriši",
    "List deleted" : "Popis je izbrisan",
    "Archive all cards" : "Arhiviraj sve kartice",
    "Delete list" : "Izbriši popis",
    "Archive all cards in this list" : "Arhiviraj sve kartice s ovog popisa",
    "Add a new card" : "Dodaj novu karticu",
    "Card name" : "Naziv kartice",
    "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
    "Edit" : "Uredi",
    "Add a new tag" : "Dodaj novu oznaku",
    "Board name" : "Naziv ploče",
    "Members" : "Članovi",
    "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
    "File to share" : "Datoteka za dijeljenje",
    "Invalid path selected" : "Odabran nevažeći put",
    "Upload new files" : "Otpremi nove datoteke",
    "Share from Files" : "Dijeli iz datoteka",
    "Add this attachment" : "Dodajte ovaj privitak",
    "Show in Files" : "Prikaži u datotekama",
    "Download" : "Preuzmi",
    "Delete Attachment" : "Izbriši privitak",
    "Restore Attachment" : "Vrati privitak",
    "Modified" : "Promijenjeno",
    "Created" : "Stvoreno",
    "The title cannot be empty." : "Naslov ne može biti prazan.",
    "Open in sidebar view" : "Otvori u bočnom prikazu",
    "Open in bigger view" : "Otvori u većem prikazu",
    "Comments" : "Komentari",
    "Failed to load comments" : "Učitavanje komentara nije uspjelo",
    "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
    "The comment cannot be empty." : "Komentar ne može biti prazan.",
    "The comment cannot be longer than 1000 characters." : "Komentar ne može duži od 1000 znakova.",
    "Save" : "Spremi",
    "Created:" : "Stvoreno:",
    "In reply to" : "Kao odgovor",
    "Cancel reply" : "Prekini odgovor",
    "Reply" : "Odgovori",
    "Update" : "Ažuriraj",
    "Write a description …" : "Napišite opis...",
    "Description" : "Opis",
    "(Unsaved)" : "(Nije spremljeno)",
    "(Saving…)" : "(Spremanje…)",
    "Formatting help" : "Pomoć pri oblikovanju",
    "Edit description" : "Uredi opis",
    "View description" : "Prikaži opis",
    "Add Attachment" : "Dodaj privitak",
    "Choose attachment" : "Odaberi privitak",
    "Select Date" : "Odaberi datum",
    "Set a due date" : "Postavi datum dospijeća",
    "Remove due date" : "Ukloni datum dospijeća",
    "Mark as done" : "Označi kao završeno",
    "Unarchive card" : "Dearhiviraj karticu",
    "Archive card" : "Arhiviraj karticu",
    "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
    "(group)" : "(grupa)",
    "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
    "Card deleted" : "Kartica je izbrisana",
    "Edit title" : "Uredi naslov",
    "Assign to me" : "Dodijeli meni",
    "Unassign myself" : "Ukloni sebe",
    "Delete card" : "Izbriši karticu",
    "seconds ago" : "prije nekoliko sekundi",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Keyboard shortcut" : "Tipkovni prečac",
    "Action" : "Radnja",
    "Shift" : "Pomakni",
    "Search" : "Traži",
    "All boards" : "Sve ploče",
    "Archived boards" : "Arhivirane ploče",
    "Shared with you" : "Podijeljeno s vama",
    "Use bigger card view" : "Prikaži veće kartice",
    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
    "Cancel edit" : "Otkaži uređivanje",
    "Board {0} deleted" : "Ploča {0} je izbrisana",
    "All cards" : "Sve kartice",
    "Only assigned cards" : "Samo dodijeljene kartice",
    "No reminder" : "Nema podsjetnika",
    "An error occurred" : "Došlo je do pogreške",
    "Delete the board?" : "Želite li izbrisati ploču?",
    "Board details" : "Pojedinosti o ploči",
    "Edit board" : "Uredi ploču",
    "Clone board" : "Kloniraj ploču",
    "Unarchive board" : "Dearhiviraj ploču",
    "Archive board" : "Arhiviraj ploču",
    "Turn on due date reminders" : "Uključi podsjetnike datuma dospijeća",
    "Turn off due date reminders" : "Isključi podsjetnike datuma dospijeća",
    "Due date reminders" : "Podsjetnici datuma dospijeća",
    "Assigned cards" : "Dodijeljene kartice",
    "No notifications" : "Nema obavijesti",
    "Delete board" : "Izbriši ploču",
    "Clone cards" : "Kloniraj kartice",
    "Advanced options" : "Napredne opcije",
    "Clone" : "Kloniraj",
    "Export" : "Izvoz",
    "Loading filtered view" : "Učitavanje filtriranog prikaza",
    "Today" : "Danas",
    "Tomorrow" : "Sutra",
    "No due" : "Nema nezavršenih",
    "Search for {searchQuery} in all boards" : "Traži {searchQuery} na svim pločama",
    "No results found" : "Nema rezultata",
    "{stack} in {board}" : "{stack} u {board}",
    "Create card" : "Stvori karticu",
    "Create a new card" : "Stvori novu karticu",
    "Card title" : "Naslov kartice",
    "Creating the new card …" : "Stvaranje nove kartice…",
    "Card \"{card}\" was added to \"{board}\"" : "Kartica „{card}” je dodana na „{board}”",
    "Open card" : "Otvori karticu",
    "Close" : "Zatvori",
    "No upcoming cards" : "Nema nadolazećih kartica",
    "upcoming cards" : "nadolazeće kartice",
    "Link to a board" : "Poveznica na ploču",
    "Link to a card" : "Poveznica na karticu",
    "Create a card" : "Stvori karticu",
    "Message from {author} in {conversationName}" : "Poruka od {author} u {conversationName}",
    "Something went wrong" : "Nešto je pošlo po krivu",
    "Failed to upload {name}" : "Neuspješno otpremanje {name}",
    "Maximum file size of {size} exceeded" : "Prekoračena je maksimalna veličina datoteke od {size}",
    "Due date" : "Datum dospijeća",
    "Error creating the share" : "Pogreška pri stvaranju dijeljenja",
    "Share with a Deck card" : "Dijeli s Deck karticom",
    "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
    "Share" : "Dijeli",
    "Personal" : "Osobno",
    "To do" : "Zadatak",
    "Doing" : "U postupku",
    "Example Task 3" : "Primjer zadatka 3.",
    "Example Task 2" : "Primjer zadatka 2.",
    "Example Task 1" : "Primjer zadatka 1.",
    "Move card to another board" : "Premjesti karticu na drugu ploču"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
